function GproteinCycle
a = [1/4 1/2 1 2 4 6 8]
%Initial conditions vector
for i = 1:7
x0=zeros(7,1);
x0(1) = 6.02E17*a(i);
x0(2) = 10000.0;
x0(3) = 7000.0;
x0(4) = 3000.0;
x0(5) = 3000.0;
x0(6) = 0.0;
x0(7) = 0.0;


%Creating linespace
t=linspace(0,20,100);

%Solving equations
[t,x]=ode23s(@f,t,x0);
Ligand(:,i)=x(:,1);%concentration of Ligand
% Receptor(:,i)=x(:,2);%concentration of Receptor
% GaGDP(:,i)=x(:,5);%concentration of Ligand
Gbc(:,i) = x(:,4);%concentration of G-beta-gamma dimer
assignin('base','Ligand',Ligand);
assignin('base','Gbc',Gbc);
assignin('base','Time',t);

end
%Concentration of Free b beta gamma vs G-alpha-GDP

% subplot 211
% plot(t,x(:,5));
% legend('8 * initial concentration of G-alpha GDP')
% xlabel('Time(s)');ylabel('Molecules/litre');
% title ('Promoter strength analysis');
% 
% subplot 212
% plot(t,x(:,4));
% legend('Free G-beta-gamma concentration')
% xlabel('Time(s)');ylabel('Molecules/litre');


% %ploting the results
% plot(t,x(:,1),'r--',t,x(:,2),'k',t,x(:,4),'b',t,x(:,6),'m');
% legend('Ligand','Receptor','Free - G-beta-gamma','G-alpha-GTP')
% plot(t,x);
end

function xdot=f(t,x)
% Compartment: id = cell, name = cell, constant
	compartment_cell=1.0;
% Reaction: id = reaction_0, name = Ligand-Receptor Association

	% Local Parameter:   id =  k1, name = k1
	reaction_reaction_0_k1=3.32E-18;
	% Local Parameter:   id =  k2, name = k2
	reaction_reaction_0_k2=0.01;

	reaction_reaction_0=compartment_cell*(reaction_reaction_0_k1*x(1)*x(2)-reaction_reaction_0_k2*x(7));
% Reaction: id = reaction_1, name = Receptor Synthesis

	% Local Parameter:   id =  v, name = v
	reaction_reaction_1_v=4.0;

	reaction_reaction_1=compartment_cell*reaction_reaction_1_v;
% Reaction: id = reaction_2, name = Receptor Degradation

	% Local Parameter:   id =  k1, name = k1
	reaction_reaction_2_k1=4.0E-4;

	reaction_reaction_2=compartment_cell*reaction_reaction_2_k1*x(2);
% Reaction: id = reaction_3, name = Heterotrimeric G-Protein Formation

	% Local Parameter:   id =  k1, name = k1
	reaction_reaction_3_k1=1.0;

	reaction_reaction_3=compartment_cell*reaction_reaction_3_k1*x(5)*x(4);
% Reaction: id = reaction_4, name = G-protein Activation

	% Local Parameter:   id =  k1, name = k1
	reaction_reaction_4_k1=1.0E-5;

	reaction_reaction_4=compartment_cell*reaction_reaction_4_k1*x(7)*x(3);
% Reaction: id = reaction_5, name = Receptor-Ligand Degradation

	% Local Parameter:   id =  k1, name = k1
	reaction_reaction_5_k1=0.0040;

	reaction_reaction_5=compartment_cell*reaction_reaction_5_k1*x(7);
% Reaction: id = reaction_6, name = G-protein Inactivation 

	% Local Parameter:   id =  k1, name = k1
	reaction_reaction_6_k1=0.11;

	reaction_reaction_6=compartment_cell*reaction_reaction_6_k1*x(6);
	xdot=zeros(7,1);
	% Species:   id = L, name = Ligand, affected by kineticLaw

	xdot(1) = (1/(compartment_cell))*((-1.0 * reaction_reaction_0));

	% Species:   id = R, name = Receptor, affected by kineticLaw

	xdot(2) = (1/(compartment_cell))*((-1.0 * reaction_reaction_0) + ( 1.0 * reaction_reaction_1) + (-1.0 * reaction_reaction_2));

	% Species:   id = G, name = Inactive heterotrimeric G-protein, affected by kineticLaw

	xdot(3) = (1/(compartment_cell))*(( 1.0 * reaction_reaction_3) + (-1.0 * reaction_reaction_4));

	% Species:   id = Gbg, name = Free levels of G-beta-gamma, affected by kineticLaw

	xdot(4) = (1/(compartment_cell))*((-1.0 * reaction_reaction_3) + ( 1.0 * reaction_reaction_4));

	% Species:   id = Gd, name = G-alpha-GDP, affected by kineticLaw

	xdot(5) = (1/(compartment_cell))*((-1.0 * reaction_reaction_3) + ( 1.0 * reaction_reaction_6));

	% Species:   id = Ga, name = G-alpha-GTP, affected by kineticLaw

	xdot(6) = (1/(compartment_cell))*(( 1.0 * reaction_reaction_4) + (-1.0 * reaction_reaction_6));

	% Species:   id = RL, name = Receptor-Ligand, affected by kineticLaw

	xdot(7) = (1/(compartment_cell))*(( 1.0 * reaction_reaction_0) + (-1.0 * reaction_reaction_5));
end